@@ -16,6 +16,7 @@
 
 use crate::traits::AllocatableError;
 use crate::traits::RecordResolvableError;
+use it_memory_traits::MemoryAccessError;
 use thiserror::Error as ThisError;
 
 #[derive(Debug, ThisError)]
@@ -25,4 +26,7 @@ pub enum LoError {
 
     #[error("{0}")]
     RecordResolvableError(#[from] RecordResolvableError),
+
+    #[error("{0}")]
+    MemoryAccessError(#[from] MemoryAccessError),
 }
