@@ -27,15 +27,15 @@ pub use lower_array::array_lower_memory;
 pub use lower_array::LoweredArray;
 pub use lower_record::record_lower_memory;
 
-pub use it_memory_traits::SequentialMemoryView;
+pub use it_memory_traits::MemoryView;
 
 pub type LoResult<T> = std::result::Result<T, error::LoError>;
 
-pub struct ILowerer<'m, A: Allocatable, MV> {
+pub struct ILowerer<'m, A: Allocatable<MV>, MV: MemoryView> {
     pub writer: MemoryWriter<'m, A, MV>,
 }
 
-impl<'m, A: Allocatable, MV: for<'a> SequentialMemoryView<'a>> ILowerer<'m, A, MV> {
+impl<'m, A: Allocatable<MV>, MV: MemoryView> ILowerer<'m, A, MV> {
     pub fn new(view: MV, allocatable: &'m A) -> LoResult<Self> {
         let writer = MemoryWriter::new(view, allocatable)?;
         let lowerer = Self { writer };
